# settings-vial Change Log

## [0.1.0] - 2019-07-29

### Added
- Prefixed environment variables loading
- Dynamic settings support

The format is based on [Keep a Changelog](http://keepachangelog.com/)
and should contain all notable changes to the project made for humans.

## [Unreleased]

All unreleased changes should be added to appropriate section below

### Added
New features
-

### Changed
Changes in existing functionality
-

### Deprecated
Once-stable features removed in upcoming releases
-

### Removed
Deprecated featured removed in this release
-

### Fixed
Any bug fixes
-

### Security
Invite users to upgrade in case of vulnerabilities
-

## [0.0.1] - YYYY-MM-DD

Adhere to [semantic versioning](http://semver.org/) and [ISO date format](http://www.iso.org/iso/home/standards/iso8601.htm)
